@@ -1,7 +1,7 @@
 /****************************************************************************
 **  CUBE        http://www.scalasca.org/                                   **
 *****************************************************************************
-**  Copyright (c) 1998-2016                                                **
+**  Copyright (c) 1998-2022                                                **
 **  Forschungszentrum Juelich GmbH, Juelich Supercomputing Centre          **
 **                                                                         **
 **  Copyright (c) 2009-2015                                                **
@@ -67,7 +67,7 @@ static int MAXDEPTH       = 3;
 
 
 void
-create_cube_structure( cube_t*,
+create_cube_structure( cube_t*       cube,
                        cube_metric** metrics,
                        cube_cnode**  cnodes,
                        unsigned      Nthreads );
@@ -84,9 +84,9 @@ fill_cube_type_int64_row( cube_type_int64* row,
 void
 create_calltree( cube_t*       cube,
                  cube_region** regn,
-                 cube_cnode**  codes,
+                 cube_cnode**  cnodes,
                  int*          idx,
-                 int*          reg_idx,
+                 int*          region_idx,
                  cube_cnode*   parent,
                  int           level );
 int
@@ -120,7 +120,7 @@ main( int argc, char* argv[] )
 
 
 
-    char* cubefile = "example_ghost4remap";
+    char* cubefile = "example_ghost";
 
 
     //    FILE* fp = fopen(cubefile, "w");
@@ -159,7 +159,7 @@ main( int argc, char* argv[] )
         }
         carray* sequence = cube_get_cnodes_for_metric( cube, metrics_vector[ mi ] );
 
-        unsigned ci = 0;
+        uint32_t ci = 0;
         for ( ci = 0; ci < sequence->size; ci++ )
         {
             if ( metrics_vector[ mi ]->dtype_params->type == CUBE_DATA_TYPE_DOUBLE )
@@ -226,6 +226,22 @@ create_cube_structure( cube_t* cube, cube_metric** metrics, cube_cnode** cnodes,
                                  "@mirror@patterns-2.1.html#execution",
                                  "Total CPU allocation time", NULL, CUBE_METRIC_EXCLUSIVE );
 
+    cube_metric_set_viz_type( metrics[ 0 ], CUBE_METRIC_GHOST );
+
+
+    metrics[ 1 ] = cube_def_met( cube, "Experimenal metric 1", "exp1", "FLOAT", "sec", "",
+                                 "http://www.cs.utk.edu/sys.html",
+                                 "Experimental metric 1 with some issues ", NULL,  CUBE_METRIC_PREDERIVED_EXCLUSIVE );
+    metrics[ 2 ] = cube_def_met( cube, "Experimenal metric 2", "exp2", "FLOAT", "sec", "",
+                                 "http://www.cs.utk.edu/sys.html",
+                                 "Completely wrong metric", NULL,  CUBE_METRIC_PREDERIVED_EXCLUSIVE );
+
+    char* expression1 = " {   ${a}=0;   if (${cube::region::name}[${calculation::region::id}] =~ /^MPI_/)    {        ${a}=metric::time();     };  return ${a};   }   ";
+    char* expression2 = " {   ${a}=0;   if ( not(${cube::region::name}[${calculation::region::id}] =~ /^MPI_/))    {        ${a}=metric::time();     };  return ${a};   }  ";
+
+    cube_metric_set_expression( metrics[ 1 ], expression1 );
+    cube_metric_set_expression( metrics[ 2 ], expression2 );
+
 
     /* define call tree */
     char* mod = "/ICL/CUBE/example.c";
@@ -536,7 +552,7 @@ create_calltree( cube_t* cube, cube_region** regn, cube_cnode** cnodes, int* idx
         return;
     }
     int _num_children = get_next_random();
-    for ( unsigned i = 0; i < _num_children; i++ )
+    for ( int i = 0; i < _num_children; i++ )
     {
         unsigned rand_reg = *region_idx;
         *region_idx = ( ( *region_idx + 1 ) % 169 );      // cyclic selection of regions
